close all
clear 

%1 - plasticity control 
%2 - plasticity with startle at -100ms 
%3 - plasticity with startle at 0ms 


for dataset=1:3
disp(['dataset ' num2str(dataset)])
fnamepath='E:\RVR\Analysis\Datafiles\';
dataname={'plasticitycontrol','plasticitystartle100','plasticitystartle'};

load([fnamepath 'Data_' dataname{dataset}])

%define basic parameters
nsubj=length(ang);
nang=length(unique(ang{1}));
ntrials=960;
nreps=40;
nblocks=6;
srateEMG=5000;
tbef=1000*fullsweepbef/srateEMG;
taft=1000*fullsweepaft/srateEMG; 
RVRbef=75*srateEMG/1000+fullsweepbef;
RVRaft=125*srateEMG/1000+fullsweepbef;

%output matrices
mRTmat=NaN(nsubj,nreps,nblocks,nang);
Tsmat=NaN(nsubj,nreps,nblocks,nang);
TTmat=NaN(nsubj,nreps,nblocks,nang);
meanbaseline=NaN(nsubj,nang);
medianbaseline=NaN(nsubj,nang);
sweepmat=NaN(nsubj,nreps,nblocks,nang,fullsweepbef+fullsweepaft+1);
RVR=NaN(nsubj,nreps,nblocks,nang);
VOL=NaN(nsubj,nreps,nblocks,nang);
movementonset=NaN(nsubj,nblocks,nang);
directionexcluded=NaN(nsubj,nblocks,nang);
inctrials=NaN(nsubj,1);

for subj=1:nsubj
    
    %extract data for each subject
    angS=ang{subj};
    angS=angS(1:ntrials);
    sweepsS=sweeps{subj};
    sweepsS=squeeze(sweepsS(1,1:ntrials,:));
    Ts=T{subj}; %time to target in seconds
    Ts=Ts(1:ntrials);
    TT=NaN(ntrials,1);
    tstS=tst{subj};
    tstS=tstS(1:ntrials);
    xposS=xpos{subj};
    yposS=ypos{subj};
       
    %change order to match angle orientations
    angS=changem(angS,[2 1 4 3],unique(angS));
    
    %create block list
    blocklist=repmat(1:nblocks,nang*nreps,1);
    blocklist=blocklist(:);

    
    %% Calculate exclusion criteria measures 
    %  manual RT for each trial (defined as time when hand velocity exceed 5% of maximum hand velocity)
    %  trial direction (hand position at manualRT+50ms) 
    
    manualRT=zeros(1,ntrials);
    direction=ones(1,ntrials);
    
    %convert time values to position sampling rate 
    tstXY=round(tstS*1000);
    Txy=round(Ts*1000); 
    
    %preallocate path length
    pathlength=NaN(length(tstS),1);
    
    for t=1:length(tstS)        
        %define position data for each trial (from trial start time to in target time)
        tx=xposS(tstXY(t):tstXY(t)+Txy(t));
        ty=yposS(tstXY(t):tstXY(t)+Txy(t));
        
        %align each trial on zero
        tx=tx-tx(1);
        ty=ty-ty(1);
               
        %calculate straightline distance from start to each time point        
        straightlinedist=NaN(1,length(ty));
        for ii=1:length(ty)
            straightlinedist(ii)=sqrt(tx(ii)^2 + ty(ii)^2);
        end
        
        %calculate time to reach target distance (removing importance of accuracy)
        TT(t)=find(straightlinedist>=straightlinedist(end),1);
        
        %calculate manual RT as the time taken to reach 5mm (=0.25) straight line distance
        manualRT(t)=find(straightlinedist>0.25,1); 
        
        %calculate position of trial at t=mRT
        txANG=tx(manualRT(t));
        tyANG=ty(manualRT(t));
        
        %calculate quadrant of trial
        if txANG<0 && tyANG>0,     vecang=1; exang=4; %top right
        elseif txANG>0 && tyANG>0, vecang=2; exang=3; %top left
        elseif txANG<0 && tyANG<0, vecang=3; exang=2; %bottom right
        elseif txANG>0 && tyANG<0, vecang=4; exang=1; %bottom left
        else
            vecang=NaN;
        end

        %exclude trials in wrong direction (opposite quarter)
        if exang==angS(t)
            direction(t)=0; %0-wrong direction, 1-right direction
        end
        
    end
    

    %%  Apply exclusion criteria  
    
    %exclude trials with greater pre-zero activity than post-zero activity
    sweepspre=max(sweepsS(:,1:fullsweepbef),[],2);
    sweepspost=max(sweepsS(:,fullsweepbef:end),[],2);
    sweepex=sweepspre>sweepspost;
    
    %combine exclusion criteria
    exindex=direction==0 | TT'>500 | sweepex'==1;
    
    %excluded trials 
    sweepsS(exindex==1,:)=NaN; 
    Ts(exindex==1)=NaN;
    TT(exindex==1)=NaN;
 
    %export number of error trials made per blocks
    for B=1:nblocks
        for A=1:nang
            directionexcluded(subj,B,A)=sum(blocklist'==B & direction==0 & angS'==A);
        end
    end
    
    
    %% Group sweeps into matrix
    
    for B=1:nblocks
        for A=1:nang
            triallist=find(blocklist==B & angS==A);
            triallist(nreps+1:end)=[];
            mRTmat(subj,1:length(triallist),B,A)=manualRT(triallist);
            sweepmat(subj,1:length(triallist),B,A,:)=sweepsS(triallist,:);            
            Tsmat(subj,1:length(triallist),B,A)=round(Ts(triallist)*srateEMG); %time to target in dp (from s)
            TTmat(subj,1:length(triallist),B,A)=round(TT(triallist)/1000*srateEMG); %time to target distance in dp (from ms)
            movementonset(subj,B,A)=nanmean(manualRT(triallist));
        end
    end
    
    %calculate baseline (for each trial)
    trialbaseline=squeeze(nanmean(sweepmat(subj,:,:,:,1:fullsweepbef),5));
    
    %subtract baseline from all sweeps
    sweepmat(subj,:,:,:,:)=squeeze(sweepmat(subj,:,:,:,:))-repmat(trialbaseline,1,1,1,fullsweepbef+fullsweepaft+1);
        
    %update number of included trials
    inctrials(subj)=100*sum(~isnan(Tsmat(subj,:)))/ntrials;
    
    %calculate mean baseline
    meanbaseline(subj,:)=nanmean(sweepmat(subj,:,:,:,1:fullsweepbef),1:5);
    medianbaseline(subj,:)=nanmedian(sweepmat(subj,:,:,:,1:fullsweepbef),1:5);
    
    %calculate AUC for RVR 
    RVR(subj,:,:,:)=squeeze(trapz(sweepmat(subj,:,:,:,RVRbef:RVRaft),5));
    
    %calculate AUC for voluntary response (1 to time to target distance) 
    for t=1:nreps
        for B=1:nblocks
            for A=1:nang
                if ~isnan(TTmat(subj,t,B,A))
                    VOL(subj,t,B,A)=squeeze(trapz(sweepmat(subj,t,B,A,fullsweepbef:fullsweepbef+TTmat(subj,t,B,A))));
                end
            end
        end
    end
    
end


%% EMG onset calculations

%calculate mean sweep
sweepmean=squeeze(nanmean(sweepmat,2));
sweepmedian=squeeze(nanmedian(sweepmat,2));

%calculate EMG latency from mean sweep
EMGonset=NaN(nsubj,nblocks,nang);

%calculate EMG latency for each sweep average
for subj=1:nsubj
    for A=1:nang
        for B=1:nblocks
            %select data
            data=squeeze(sweepmat(subj,:,B,A,:));
            %define average sweep and smooth
            meansweep=nanmean(data);
            mediansweep=nanmedian(data);
            threshold=nanmean(mediansweep(1:2500))+2*nanstd(mediansweep(1:2500));
            EMGabovethreshold=mediansweep'>threshold;
            a=diff([1; EMGabovethreshold; -1]);
            posturn=find(a>=1); 
            negturn=find(a<=-1);
            if ~isempty(posturn) && ~isempty(negturn)
                negturn(negturn(1)<posturn(1))=[];
                numturns=min([length(posturn) length(negturn)]);  
                b=negturn(1:numturns)-posturn(1:numturns);
                ind=find(b>250,1); %sweep must exceed threshold for 50ms (250dp)
                if ~isempty(ind)
                    EMGonset(subj,B,A)=posturn(ind)-fullsweepbef; 
                elseif sum(EMGabovethreshold)>0
                    EMGonset(subj,B,A)=1;
                end
            end
        end
    end
end


%% output data 

save([fnamepath 'Output_' dataname{dataset}],'EMGonset','mRTmat','Tsmat','TTmat','meanbaseline','medianbaseline','sweepmean','sweepmedian','nsubj','nang','nblocks','nreps',...
    'srateEMG','tbef','taft','fullsweepbef','fullsweepaft','sweepmat','VOL','RVR','movementonset','directionexcluded','inctrials')

end

