% extracts all data from all subjects in a given protocol to be used in other scripts
% xpos, ypos, trial start times (tst), ang, isstim, in target times (T), sweeps (-500 to 1000ms)
% output is a data file with cell arrays indexed for each subject

clear all
close all

%% Choose dataset

fileroot='E:\RVR\';

for dataset=1

%1 - plasticity with startle at 0ms 
%2 - plasticity control  
%3 - plasticity with startle at -100ms 


if dataset==1
%% Plasticity with startle at 0ms (healthy controls)
    
    filename='plasticitystartle'; %output file 
    noise=50;
    sm=5;  %sigma of Gaussian smoothing - 0 for none
    emgch=[1 2]; %emg channels recorded 
    rig=0; %home rig
    
    fname={fname1; fname2; fname3; fname4; fname5; fname6; fname7; fname8; fname9; fname10; fname11; fname12; fname13; fname14; fname15};
    gain=[2000 2000; 2000 5000; 2000 5000; 10000 10000; 2000 5000; 2000 5000; 1000 2000; 2000 2000; 2000 2000; 5000 5000; 5000 5000; 5000 5000; 2000 2000; 2000 5000; 5000 5000];
    hand={'r','r','r','r','r','r','r','r','r','r','r','r','r','r','r'};


elseif dataset==2
%% Plasticity control (healthy controls)
    
    filename='plasticitycontrol'; %output file 
    noise=50;
    sm=5;  %sigma of Gaussian smoothing - 0 for none
    emgch=[1 2]; %emg channels recorded 
    rig=0; %home rig
    
    fname={fname1; fname2; fname3; fname4; fname5; fname6; fname7; fname8; fname9; fname10; fname11; fname12; fname13; fname14};
    gain=[5000 5000; 6000 4000; 4500 5000; 4500 7200; 3000 4000; 3000 4000; 4000 5000; 3000 4000; 1500 2000; 3000 4000; 1800 2000; 4000 6000; 3000 3000; 2250 3000];
    hand={'r','r','r','r','r','r','r','r','r','r','r','r','r','r','r'};
    
    
elseif dataset==3
%% Plasticity with startle at -100ms (healthy controls)
    
    filename='plasticitystartle100'; %output file 
    noise=50;
    sm=5;  %sigma of Gaussian smoothing - 0 for none
    emgch=[1 2]; %emg channels recorded 
    rig=0; %home rig

    gain=[4000 5000; 5000 4000; 2000 6000; 7200 7200; 4000 5000; 3000 4000; 3000 4000; 2000 3000; 1500 2000; 3000 5000; 2000 3000; 4000 6000; 3000 3000; 2500 3600];
    fname={fname1; fname2; fname3; fname4; fname5; fname6; fname7; fname8; fname9; fname10; fname11; fname12; fname13; fname14};
    hand={'r','r','r','r','r','r','r','r','r','r','r','r','r','r','r'};
   
    
end


%% EXTRACT DATA 

xpos=cell(1,length(fname));
ypos=cell(1,length(fname));
tst=cell(1,length(fname));
ang=cell(1,length(fname));
isstim=cell(1,length(fname));
stimtimes=cell(1,length(fname));
T=cell(1,length(fname));
sweeps=cell(1,length(fname));

for i=1:length(fname)
    disp(i)
    tic
    
    [xposS,yposS,tstS,angS,isstimS,stimtimesS,TS,sweepsS,fullsweepbef,fullsweepaft]=extractdata([fileroot fname{i}],i,noise,sm,emgch,hand{i},rig,dataset,gain(i,:));  
    
    xpos{i}=xposS;
    ypos{i}=yposS;
    tst{i}=tstS;
    ang{i}=angS;
    isstim{i}=isstimS;
    stimtimes{i}=stimtimesS;
    T{i}=TS;
    sweeps{i}=sweepsS;
    
    toc
    clearvars -except fileroot fname i noise sm emgch hand rig dataset xpos ypos tst ang isstim stimtimes T sweeps filename fullsweepbef fullsweepaft gain
    
end
    
%export variables to data file 
tic
save([fileroot 'Analysis\Datafiles\Data_' filename],'xpos','ypos','tst','ang','isstim','stimtimes','T','sweeps','fullsweepbef','fullsweepaft','-v7.3')
toc

end

