function [xpos,ypos,tst,ang,isstim,stimtimes,T,sweeps,sweepbef,sweepaft]=extractdata(fname,i,noise,sm,emgch,hand,rig,dataset,gain)

sonfile=openSMR([fname,'.smr']);

%% define sweep length

SR=5000;
sweepbef=0.7*SR;
sweepaft=1.0*SR;
sweeplength=sweepbef+sweepaft+1;


%% define xy position

xpos=readSMRadc(sonfile,10,0,inf);
ypos=readSMRadc(sonfile,11,0,inf);


%% define trial start times

tstart=readSMRevents(sonfile,12);
tstart=tstart(2:2:end);


%% define first in target time for each trial 

targetindex=zeros(length(tstart),1);
target=readSMRevents(sonfile,13);
target=target(1:2:end);
for j=1:length(tstart)
    targetindex(j)=find(target>tstart(j),1,'first');
end
intarget=target(targetindex); %in target time in seconds relative to start of recording 


%% define trial start times using diode

diode=readSMRadc(sonfile,5,0,inf);

%for home rig
if rig==0

    diode_tst=round(tstart*SR);
    diodebase=zeros(1,length(diode_tst)-1);
    for ii=1:length(diode_tst)-1
        diodebase(ii)=mean(diode((diode_tst(ii+1)-5000):diode_tst(ii+1)));
    end
    diodemean=mean(diodebase);
    diodestd=std(diodebase);
    diode_thresh=find(diode<diodemean-diodestd*5);

%for travel rig
elseif rig==1
    
    %smooth diode channel
    smdiode=5;
    xdiode=-smdiode*2:1000/SR:smdiode*2;
    smdiodecoef=normpdf(xdiode,0,smdiode);
    smdiodecoef=smdiodecoef/sum(smdiodecoef);    

    diode_tst=round(tstart*SR);
    diode_int=round(intarget*SR);
    diodehighbase=zeros(1,length(tstart));
    diodelowbase=zeros(1,length(tstart));
    
    diode=conv(diode,smdiodecoef,'same');
    for ii=1:length(tstart)
        diodehighbase(ii)=mean(diode((diode_tst(ii)-SR):diode_tst(ii)));
        diodelowbase(ii)=mean(diode((diode_int(ii)-SR):diode_int(ii)));
    end
    diodehighmean=mean(diodehighbase);
    diodelowmean=mean(diodelowbase);
    meandiff=diodehighmean-diodelowmean;
    diode_thresh=find(diode<(diodelowmean+meandiff*0.90));

end

%calculate new trial start times (in seconds)
Dindex=NaN(1,length(diode_tst));
for ii=1:length(diode_tst)
    Dindex(ii)=find(diode_thresh>diode_tst(ii),1,'first');
end
tst=diode_thresh(Dindex)/SR;


%% calculate in target time relative to diode tst 

T=target(targetindex)-tst;


%% define target direction for each trial

cond=readSMRadc(sonfile,6,0,inf);
j=round((tstart+0.2)*sonfile.srate(6))+1;
cond=cond(j);
ang=round(cond);

%swap angles for lefthanded participants 
if strcmp(hand,'l')
   ang=changem(ang,[2 1 4 3],[1 2 3 4]); 
end


%% define stimulus for each trial

cond=readSMRadc(sonfile,16,0,inf);
j=round((tstart+0.2)*sonfile.srate(16))+1;
cond=cond(j);
isstim=round(cond+6); 

%read stimulus latency relative to trial start time (vestibular stim)
if dataset==3
    stimchan=readSMRadc(sonfile,9,0,inf);
    stimthresh=stimchan>1;
    stimdiff=diff(stimthresh);
    stimtimes1=find(stimdiff==1)/SR;
    stimtimes=stimtimes1-tst(isstim>1);
else 
    stimtimes1=readSMRevents(sonfile,14);
    if ~isempty(stimtimes1)
        stimtimes=stimtimes1-tst(isstim>1);
    else 
        stimtimes=0;
    end
end


%% extract data for emg channel  

sweeps=NaN(length(emgch),length(tst),sweeplength);
tstS=round(tst*SR);
for chan=1:length(emgch)
    data=readSMRadc(sonfile,emgch(chan),0,inf);
    
    %adjust for gain
    data=data/gain(emgch(chan));
    
    %high pass filter data at 30Hz for dataset , subject 8
    if i==8 && dataset==1 || dataset==2 || dataset==5 
        fco=fir1(500,30/2500,'high');
        data=conv(data,fco,'same');
    end

    %remove 50Hz noise and rectify
    data=removes50(data,sonfile,emgch(chan),noise);
    data=abs(data-mean(data));

    %smooth data
    if sm~=0
     x=-sm*2:1000/sonfile.srate(emgch(chan)):sm*2;
     smcoef=normpdf(x,0,sm);
     smcoef=smcoef/sum(smcoef); 
     data=conv(data,smcoef,'same');
    end
    
    %extract sweeps
    for ii=1:length(tst)
        sweeps(chan,ii,:)=data((tstS(ii)-sweepbef):(tstS(ii)+sweepaft));
    end
end


%% close sonfile 

closeSMR(sonfile)


